import { SIZE_OF_EMPTY_ARRAY } from '@/constants/common';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { modelsNameMapSelector } from '@/redux/models/models.selectors';
import { StandarizedPublication } from '@/types/publications';
import { useState } from 'react';
import { getBasePublications } from './getBasePublications';
import { getStandarizedPublication } from './getStandarizedPublications';

export type DownloadPublicationsAsCSVFile = () => Promise<void>;

interface UseDownloadPublicationsAsCSVFileResult {
  downloadPublicationsAsCSVFile: DownloadPublicationsAsCSVFile;
  isLoading: boolean;
}

export const useDownloadPublicationsAsCSVFile = (): UseDownloadPublicationsAsCSVFileResult => {
  const [isLoading, setIsLoading] = useState<boolean>(false);
  const [publications, setPublications] = useState<StandarizedPublication[]>([]);
  const modelNameIdMap = useAppSelector(modelsNameMapSelector);

  const getPublicationsAsList = async (): Promise<StandarizedPublication[]> => {
    if (publications.length > SIZE_OF_EMPTY_ARRAY) {
      return publications;
    }

    const basePublications = await getBasePublications({
      length: 100, // TODO: change for number of all elements
    });

    const standarizedPublications = await Promise.all(
      basePublications.map(async publication =>
        getStandarizedPublication(publication, {
          modelNameIdMap,
        }),
      ),
    );

    setPublications(standarizedPublications);
    return standarizedPublications;
  };

  const downloadPublicationsAsCSVFile = async (): Promise<void> => {
    setIsLoading(true);
    const data = await getPublicationsAsList();
    setIsLoading(false);

    console.log({ data });
  };

  return {
    downloadPublicationsAsCSVFile,
    isLoading,
  };
};
